@@ -1,10 +1,13 @@
-#!/home/markt/bin/perl -w
+#!/home/markt/usr/local/Linux/bin/perl -w
 use strict;
 no strict 'subs';
 use Java;
 
-my $java = new Java();
+my $java = new Java(host=>"laggard");
 
+my $obj = $java->create_object("thot.Test","mark");
+print $obj->get->get_value;
+exit;
 my $class = $java->java_lang_Class("forName","Test");
 my $constructors = $class->getConstructors();
 my $v = $constructors->{name};
